.. include:: ../README.rst

.. include:: internals.rst

Show me the code
----------------
Check the code to see details.

.. toctree::
   :maxdepth: 2

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
